==============================
Qruise Calibration User Manual
==============================

This is the documentation of **Qruise Calibrate (QCalibrate)** software.
The software consists of a software service
and a **qcalibrateremote** client library.


.. only:: html
    
    Offline version of the documentation is available  `here <qcalibrate.pdf>`_.

Contents
========

.. toctree::
    :maxdepth: 2

    Quickstart <quickstart>
    System Overview <overview>
    Web user interface <web>
    Client library (qcalibrateremote) <qcalibrateremote>
    Authors <authors>
    Changelog <changelog>

Indices and tables
==================

* :ref:`genindex`
    
.. _toctree: http://www.sphinx-doc.org/en/master/usage/restructuredtext/directives.html
.. _reStructuredText: http://www.sphinx-doc.org/en/master/usage/restructuredtext/basics.html
.. _references: http://www.sphinx-doc.org/en/stable/markup/inline.html
.. _Python domain syntax: http://sphinx-doc.org/domains.html#the-python-domain
.. _Sphinx: http://www.sphinx-doc.org/
.. _Python: http://docs.python.org/
.. _Numpy: http://docs.scipy.org/doc/numpy
.. _SciPy: http://docs.scipy.org/doc/scipy/reference/
.. _matplotlib: https://matplotlib.org/contents.html#
.. _Pandas: http://pandas.pydata.org/pandas-docs/stable
.. _Scikit-Learn: http://scikit-learn.org/stable
.. _autodoc: http://www.sphinx-doc.org/en/stable/ext/autodoc.html
.. _Google style: https://github.com/google/styleguide/blob/gh-pages/pyguide.md#38-comments-and-docstrings
.. _NumPy style: https://numpydoc.readthedocs.io/en/latest/format.html
.. _classical style: http://www.sphinx-doc.org/en/stable/domains.html#info-field-lists

.. automodule:: qcalibrateremote
    :ignore-module-all: